@@ -1,3 +1,18 @@
+# Copyright (C) 2021-2022 Koen Derks
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 #' Test of Repeated Values
 #'
 #' @description This function analyzes the frequency with which values get repeated within a set of numbers. Unlike Benford's law, and its generalizations, this approach examines the entire number at once, not only the first or last digit.
@@ -96,7 +111,7 @@ rv.test <- function(x, check = 'last', method = 'af', B = 2000) {
                  integers = table(integers),
                  decimals = table(decimals),
                  n = n,
-                 cor.test = if (class(cortest) != "try-error") cortest else NULL,
+                 cor.test = if (!inherits(cortest, "try-error")) cortest else NULL,
                  check = check,
                  method = method,
                  data.name = dname)
